@@ -86,7 +86,7 @@
 #define BLUEZQT_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef BLUEZQT_NO_DEPRECATED
-#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55a00
+#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55c00
 #endif
 #ifdef BLUEZQT_NO_DEPRECATED_WARNINGS
 #  define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define BLUEZQT_DEPRECATED_WARNINGS_SINCE BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0x55a00
+#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0x55c00
 #  endif
 #endif
 
@@ -180,7 +180,7 @@
 #define BLUEZQT_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef BLUEZQT_NO_DEPRECATED
-#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55a00
+#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55c00
 #endif
 #ifdef BLUEZQT_NO_DEPRECATED_WARNINGS
 #  define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0
@@ -190,7 +190,7 @@
 #  ifdef BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define BLUEZQT_DEPRECATED_WARNINGS_SINCE BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0x55a00
+#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0x55c00
 #  endif
 #endif
 
